@@ -144,6 +144,19 @@ class TTRClient(object):
         })
         return [Feed(feed, self) for feed in r['content']]
 
+    def get_labels(self):
+        """Get a list of configured labels"""
+        r = self._get_json({'op': 'getLabels'})
+        return [Label(label, self) for label in r['content']]
+
+    def get_headlines_for_label(self, label_id, **kwargs):
+        """
+        Get headlines for specified label id. Supports the same kwargs
+            as ``get_headlines``, except for ``feed_id`` of course.
+        """
+        feed_id = -11 - int(label_id)
+        return self.get_headlines(feed_id=feed_id, **kwargs)
+
     def get_headlines(
             self,
             feed_id=-4,
@@ -331,6 +344,15 @@ class TTRClient(object):
 
         r = self._get_json({'op': 'unsubscribeFeed', 'feed_id': feed_id})
 
+    def get_pref(self, pref_name):
+        """
+        Return preference value of the specified key.
+
+        :param pref_name: Name of the preference
+        """
+        r = self._get_json({'op': 'getPref', 'pref_name': pref_name})
+        return r['content']['value']
+
 
 class RemoteObject(object):
     """
@@ -396,6 +418,18 @@ class Feed(RemoteObject):
         return self._client.get_headlines(feed_id=self.id, **kwargs)
 
 
+class Label(RemoteObject):
+    def __init__(self, attr, client):
+        super(Label, self).__init__(attr, client)
+
+    def headlines(self, **kwargs):
+        """
+        Get a list of headlines for this label. Supports the same kwargs as
+            ``Feed.headlines()``
+        """
+        return self._client.get_headlines_for_label(self.id)
+
+
 class Headline(RemoteObject):
     """This class represents Headline objects. A headline is a short version
         of an article.
